@@ -1,7 +1,7 @@
 #!/usr/bin/env -S bash -euo pipefail
 
 projectName="superfile"
-version="v1.1.4"
+version="v1.1.7.1"
 osList=("darwin" "linux" "windows")
 archList=("amd64" "arm64")
 mkdir dist
@@ -27,3 +27,4 @@ for os in "${osList[@]}"; do
         done
     fi
 done
+w
\ No newline at end of file
