@@ -1,12 +1,14 @@
 package internal
 
+// Variables for holding default configurations of each settings
 var (
 	HotkeysTomlString  string
 	ConfigTomlString   string
 	DefaultThemeString string
 )
 
-func defaultModelConfig(toggleDotFileBool bool, firstFilePanelDir string) model {
+// Generate and return model containing default configurations for interface
+func defaultModelConfig(toggleDotFileBool bool, toggleFooter bool, firstFilePanelDir string) model {
 	return model{
 		filePanelFocusIndex: 0,
 		focusPanel:          nonePanelFocus,
@@ -22,9 +24,20 @@ func defaultModelConfig(toggleDotFileBool bool, firstFilePanelDir string) model
 		fileModel: fileModel{
 			filePanels: []filePanel{
 				{
-					render:          0,
-					cursor:          0,
-					location:        firstFilePanelDir,
+					render:   0,
+					cursor:   0,
+					location: firstFilePanelDir,
+					sortOptions: sortOptionsModel{
+						width:  20,
+						height: 4,
+						open:   false,
+						cursor: Config.DefaultSortType,
+						data: sortOptionsModelData{
+							options:  []string{"Name", "Size", "Date Modified"},
+							selected: Config.DefaultSortType,
+							reversed: Config.SortOrderReversed,
+						},
+					},
 					panelMode:       browserMode,
 					focusType:       focus,
 					directoryRecord: make(map[string]directoryRecord),
@@ -43,9 +56,11 @@ func defaultModelConfig(toggleDotFileBool bool, firstFilePanelDir string) model
 			open:        false,
 		},
 		toggleDotFile: toggleDotFileBool,
+		toggleFooter:  toggleFooter,
 	}
 }
 
+// Return help menu for hotkeys
 func getHelpMenuData() []helpMenuModalData {
 	data := []helpMenuModalData{
 		{
@@ -78,13 +93,13 @@ func getHelpMenuData() []helpMenuModalData {
 		},
 		{
 			hotkey:         hotkeys.OpenHelpMenu,
-			description:    "Open help menu(hotkeylist)",
+			description:    "Open help menu (hotkeylist)",
 			hotkeyWorkType: globalType,
 		},
 		{
 			subTitle: "Panel navigation",
 		},
-	{
+		{
 			hotkey:         hotkeys.CreateNewFilePanel,
 			description:    "Create new file panel",
 			hotkeyWorkType: globalType,
@@ -99,6 +114,21 @@ func getHelpMenuData() []helpMenuModalData {
 			description:    "Toggle file preview panel",
 			hotkeyWorkType: globalType,
 		},
+		{
+			hotkey:         hotkeys.OpenSortOptionsMenu,
+			description:    "Open sort options menu",
+			hotkeyWorkType: globalType,
+		},
+		{
+			hotkey:         hotkeys.ToggleReverseSort,
+			description:    "Toggle reverse sort",
+			hotkeyWorkType: globalType,
+		},
+		{
+			hotkey:         hotkeys.ToggleFooter,
+			description:    "Toggle footer",
+			hotkeyWorkType: globalType,
+		},
 		{
 			hotkey:         hotkeys.NextFilePanel,
 			description:    "Focus on the next file panel",
@@ -210,6 +240,11 @@ func getHelpMenuData() []helpMenuModalData {
 			description:    "Delete selected items",
 			hotkeyWorkType: globalType,
 		},
+		{
+			hotkey:         hotkeys.CopyPath,
+			description:    "Copy current file or directory path",
+			hotkeyWorkType: globalType,
+		},
 		{
 			hotkey:         hotkeys.ExtractFile,
 			description:    "Extract compressed file",
