@@ -39,6 +39,35 @@ func (m *model) panelCreateNewFile() {
 
 }
 
+func (m *model) IsRenamingConflicting() bool {
+	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+	oldPath := panel.element[panel.cursor].location
+	newPath := panel.location + "/" + panel.rename.Value()
+
+	if oldPath == newPath {
+		return false
+	}
+
+	_, err := os.Stat(newPath)
+	return err == nil
+}
+
+func (m *model) warnModalForRenaming() {
+	id := shortuuid.New()
+	message := channelMessage{
+		messageId:   id,
+		messageType: sendWarnModal,
+	}
+
+	message.warnModal = warnModal{
+		open:     true,
+		title:    "There is already a file or directory with that name",
+		content:  "This operation will override the existing file",
+		warnType: confirmRenameItem,
+	}
+	channel <- message
+}
+
 // Rename file where the cusror is located
 func (m *model) panelItemRename() {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
@@ -73,10 +102,10 @@ func (m *model) deleteItemWarn() {
 	id := shortuuid.New()
 	message := channelMessage{
 		messageId:   id,
-		messageType: snedWarnModal,
+		messageType: sendWarnModal,
 	}
 
-	if isExternalDiskPath(panel.location) {
+	if !hasTrash || isExternalDiskPath(panel.location) {
 		message.warnModal = warnModal{
 			open:     true,
 			title:    "Are you sure you want to completely delete",
@@ -140,8 +169,12 @@ func (m *model) deleteSingleItem() {
 		message.processNewState = p
 		channel <- message
 	}
-	if panel.cursor == len(panel.element)-1 {
-		panel.cursor--
+	if len(panel.element) == 0 {
+		panel.cursor = 0
+	} else {
+		if panel.cursor >= len(panel.element) {
+			panel.cursor = len(panel.element) - 1
+		}
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
 }
@@ -258,8 +291,12 @@ func (m *model) completelyDeleteSingleItem() {
 		message.processNewState = p
 		channel <- message
 	}
-	if panel.cursor == len(panel.element)-1 {
-		panel.cursor--
+	if len(panel.element) == 0 {
+		panel.cursor = 0
+	} else {
+		if panel.cursor >= len(panel.element) {
+			panel.cursor = len(panel.element) - 1
+		}
 	}
 	m.fileModel.filePanels[m.filePanelFocusIndex] = panel
 }
@@ -595,7 +632,10 @@ func (m model) compressFile() {
 func (m model) openFileWithEditor() tea.Cmd {
 	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
 
-	editor := os.Getenv("EDITOR")
+	editor := Config.Editor
+	if editor == "" {
+		editor = os.Getenv("EDITOR")
+	}
 	if editor == "" {
 		editor = "nano"
 	}
@@ -608,7 +648,10 @@ func (m model) openFileWithEditor() tea.Cmd {
 
 // Open directory with default editor
 func (m model) openDirectoryWithEditor() tea.Cmd {
-	editor := os.Getenv("EDITOR")
+	editor := Config.Editor
+	if editor == "" {
+		editor = os.Getenv("EDITOR")
+	}
 	if editor == "" {
 		editor = "nano"
 	}
@@ -617,3 +660,18 @@ func (m model) openDirectoryWithEditor() tea.Cmd {
 		return editorFinishedMsg{err}
 	})
 }
+
+// Copy file path
+func (m model) copyPath() {
+	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+	if err := clipboard.WriteAll(panel.element[panel.cursor].location); err != nil {
+		outPutLog("Copy path error", panel.element[panel.cursor].location, err)
+	}
+}
+
+func (m model) copyPWD() {
+	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+	if err := clipboard.WriteAll(panel.location); err != nil {
+		outPutLog("Copy present working directory error", panel.location, err)
+	}
+}
