@@ -22,7 +22,7 @@ func (m model) sidebarRender() string {
 	if Config.SidebarWidth == 0 {
 		return ""
 	}
-	superfileTitle := sidebarTitleStyle.Render("    " + icon.SuperfileIcon + " Super File")
+	superfileTitle := sidebarTitleStyle.Render("    " + icon.SuperfileIcon + " superfile")
 	superfileTitle = ansi.Truncate(superfileTitle, Config.SidebarWidth, "")
 	s := superfileTitle
 	s += "\n"
@@ -95,23 +95,65 @@ func (m model) filePanelRender() string {
 			} else {
 				filePanelWidth = (m.fileModel.width + (m.fullWidth-Config.SidebarWidth-(4+(len(m.fileModel.filePanels)-1)*2))%len(m.fileModel.filePanels))
 			}
-			footerBorderWidth = m.fileModel.width + 7
+			footerBorderWidth = m.fileModel.width + 15
 		} else {
 			filePanelWidth = m.fileModel.width
-			footerBorderWidth = m.fileModel.width + 7
+			footerBorderWidth = m.fileModel.width + 15
 		}
+
+		sortDirectionString := ""
+		if filePanel.sortOptions.data.reversed {
+			if Config.Nerdfont {
+				sortDirectionString = icon.SortDesc
+			} else {
+				sortDirectionString = "D"
+			}
+		} else {
+			if Config.Nerdfont {
+				sortDirectionString = icon.SortAsc
+			} else {
+				sortDirectionString = "A"
+			}
+		}
+		sortTypeString := ""
+		if filePanelWidth < 23 {
+			sortTypeString = sortDirectionString
+		} else {
+			if filePanel.sortOptions.data.options[filePanel.sortOptions.data.selected] == "Date Modified" {
+				sortTypeString = sortDirectionString + icon.Space + "Date"
+			} else {
+				sortTypeString = sortDirectionString + icon.Space + filePanel.sortOptions.data.options[filePanel.sortOptions.data.selected]
+			}
+		}
+
 		panelModeString := ""
-		if filePanel.panelMode == browserMode {
-			panelModeString = icon.Browser + icon.Space + "Browser"
-		} else if filePanel.panelMode == selectMode {
-			panelModeString = icon.Select + icon.Space + "Select"
+		if filePanelWidth < 23 {
+			if filePanel.panelMode == browserMode {
+				if Config.Nerdfont {
+					panelModeString = icon.Browser
+				} else {
+					panelModeString = "B"
+				}
+			} else if filePanel.panelMode == selectMode {
+				if Config.Nerdfont {
+					panelModeString = icon.Select
+				} else {
+					panelModeString = "S"
+				}
+			}
+		} else {
+			if filePanel.panelMode == browserMode {
+				panelModeString = icon.Browser + icon.Space + "Browser"
+			} else if filePanel.panelMode == selectMode {
+				panelModeString = icon.Select + icon.Space + "Select"
+			}
 		}
 
 		f[i] += filePanelDividerStyle(filePanel.focusType).Render(strings.Repeat(Config.BorderTop, filePanelWidth)) + "\n"
 		f[i] += " " + filePanel.searchBar.View() + "\n"
 		if len(filePanel.element) == 0 {
 			f[i] += filePanelStyle.Render(" " + icon.Error + "  No such file or directory")
-			bottomBorder := generateFooterBorder(fmt.Sprintf("%s%s%s", panelModeString, bottomMiddleBorderSplit, "0/0"), footerBorderWidth)
+			bottomBorder := generateFooterBorder(fmt.Sprintf("%s%s%s%s%s", sortTypeString, bottomMiddleBorderSplit, panelModeString, bottomMiddleBorderSplit, "0/0"), footerBorderWidth)
 			f[i] = filePanelBorderStyle(m.mainPanelHeight, filePanelWidth, filePanel.focusType, bottomBorder).Render(f[i])
 		} else {
 			for h := filePanel.render; h < filePanel.render+panelElementHeight(m.mainPanelHeight) && h < len(filePanel.element); h++ {
@@ -128,13 +170,14 @@ func (m model) filePanelRender() string {
 				if filePanel.renaming && h == filePanel.cursor {
 					f[i] += filePanel.rename.View() + endl
 				} else {
-					f[i] += filePanelCursorStyle.Render(cursor+" ") + prettierName(filePanel.element[h].name, m.fileModel.width-5, filePanel.element[h].directory, isItemSelected, filePanelBGColor) + endl
+					_, err := os.ReadDir(filePanel.element[h].location);
+					f[i] += filePanelCursorStyle.Render(cursor+" ") + prettierName(filePanel.element[h].name, m.fileModel.width-5, filePanel.element[h].directory||(err == nil), isItemSelected, filePanelBGColor) + endl
 				}
 			}
 			cursorPosition := strconv.Itoa(filePanel.cursor + 1)
 			totalElement := strconv.Itoa(len(filePanel.element))
 
-			bottomBorder := generateFooterBorder(fmt.Sprintf("%s%s%s/%s", panelModeString, bottomMiddleBorderSplit, cursorPosition, totalElement), footerBorderWidth)
+			bottomBorder := generateFooterBorder(fmt.Sprintf("%s%s%s%s%s/%s", sortTypeString, bottomMiddleBorderSplit, panelModeString, bottomMiddleBorderSplit, cursorPosition, totalElement), footerBorderWidth)
 			f[i] = filePanelBorderStyle(m.mainPanelHeight, filePanelWidth, filePanel.focusType, bottomBorder).Render(f[i])
 		}
 	}
@@ -146,7 +189,6 @@ func (m model) filePanelRender() string {
 	}
 	return filePanelRender
 }
-
 func (m model) processBarRender() string {
 	// save process in the array
 	var processes []process
@@ -391,7 +433,7 @@ func (m model) typineModalRender() string {
 }
 
 func (m model) introduceModalRender() string {
-	title := sidebarTitleStyle.Render(" Thanks for use superfile!!") + modalStyle.Render("\n You can read the following information before starting to use it!")
+	title := sidebarTitleStyle.Render(" Thanks for using superfile!!") + modalStyle.Render("\n You can read the following information before starting to use it!")
 	vimUserWarn := processErrorStyle.Render("  ** Very importantly ** If you are a Vim/Nvim user, go to:\n  https://superfile.netlify.app/configure/custom-hotkeys/ to change your hotkey settings!")
 	subOne := sidebarTitleStyle.Render("  (1)") + modalStyle.Render(" If this is your first time, make sure you read:\n      https://superfile.netlify.app/getting-started/tutorial/")
 	subTwo := sidebarTitleStyle.Render("  (2)") + modalStyle.Render(" If you forget the relevant keys during use,\n      you can press \"?\" (shift+/) at any time to query the keys!")
@@ -494,6 +536,21 @@ func (m model) helpMenuRender() string {
 	return helpMenuModalBorderStyle(m.helpMenu.height, m.helpMenu.width, bottomBorder).Render(helpMenuContent)
 }
 
+func (m model) sortOptionsRender() string {
+	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+	sortOptionsContent := modalTitleStyle.Render(" Sort Options") + "\n\n"
+	for i, option := range panel.sortOptions.data.options {
+		cursor := " "
+		if i == panel.sortOptions.cursor {
+			cursor = filePanelCursorStyle.Render(icon.Cursor)
+		}
+		sortOptionsContent += cursor + modalStyle.Render(" "+option) + "\n"
+	}
+	bottomBorder := generateFooterBorder(fmt.Sprintf("%s/%s", strconv.Itoa(panel.sortOptions.cursor+1), strconv.Itoa(len(panel.sortOptions.data.options))), panel.sortOptions.width-2)
+
+	return sortOptionsModalBorderStyle(panel.sortOptions.height, panel.sortOptions.width, bottomBorder).Render(sortOptionsContent)
+}
+
 func (m model) filePreviewPanelRender() string {
 	previewLine := m.mainPanelHeight + 2
 	m.fileModel.filePreview.width += m.fullWidth - Config.SidebarWidth - m.fileModel.filePreview.width - ((m.fileModel.width + 2) * len(m.fileModel.filePanels)) - 2
@@ -513,12 +570,12 @@ func (m model) filePreviewPanelRender() string {
 		outPutLog("error get file info", err)
 		return box.Render("\n --- " + icon.Error + " Error get file info ---")
 	}
-	
+
 	ext := filepath.Ext(itemPath)
-	// check if the file is pdf file, cuz pdf will cause error
-	if ext == ".pdf" {
-		return box.Render("\n --- " + icon.Error + " Unsupported  formats ---")
-	}	
+	// check if the file is unsipported file, cuz pdf will cause error
+	if ext == ".pdf" || ext == ".torrent" {
+		return box.Render("\n --- " + icon.Error + " Unsupported formats ---")
+	}
 
 	if fileInfo.IsDir() {
 		directoryContent := ""
@@ -556,6 +613,9 @@ func (m model) filePreviewPanelRender() string {
 	}
 
 	if isImageFile(itemPath) {
+		if !m.fileModel.filePreview.open {
+            return box.Render("\n --- Preview panel is closed ---")
+        }
 		ansiRender, err := filepreview.ImagePreview(itemPath, m.fileModel.filePreview.width, previewLine, theme.FilePanelBG)
 		if err == image.ErrFormat {
 			return box.Render("\n --- " + icon.Error + " Unsupported image formats ---")
