@@ -59,38 +59,38 @@ func truncateMiddleText(text string, maxChars int, talis string) string {
 func prettierName(name string, width int, isDir bool, isSelected bool, bgColor lipgloss.Color) string {
 	style := getElementIcon(name, isDir)
 	if isSelected {
-		return stringColorRender(lipgloss.Color(style.color), bgColor).
+		return stringColorRender(lipgloss.Color(style.Color), bgColor).
 			Background(bgColor).
-			Render(style.icon+" ") +
+			Render(style.Icon+" ") +
 			filePanelItemSelectedStyle.
 				Render(truncateText(name, width, "..."))
 	} else {
-		return stringColorRender(lipgloss.Color(style.color), bgColor).
+		return stringColorRender(lipgloss.Color(style.Color), bgColor).
 			Background(bgColor).
-			Render(style.icon+" ") +
+			Render(style.Icon+" ") +
 			filePanelStyle.Render(truncateText(name, width, "..."))
 	}
 }
 
 func prettierDirectoryPreviewName(name string, isDir bool, bgColor lipgloss.Color) string {
 	style := getElementIcon(name, isDir)
-	return stringColorRender(lipgloss.Color(style.color), bgColor).
+	return stringColorRender(lipgloss.Color(style.Color), bgColor).
 		Background(bgColor).
-		Render(style.icon+" ") +
+		Render(style.Icon+" ") +
 		filePanelStyle.Render(name)
 }
 
 func clipboardPrettierName(name string, width int, isDir bool, isSelected bool) string {
 	style := getElementIcon(name, isDir)
 	if isSelected {
-		return stringColorRender(lipgloss.Color(style.color), footerBGColor).
+		return stringColorRender(lipgloss.Color(style.Color), footerBGColor).
 			Background(footerBGColor).
-			Render(style.icon+" ") +
+			Render(style.Icon+" ") +
 			filePanelItemSelectedStyle.Render(truncateTextBeginning(name, width, "..."))
 	} else {
-		return stringColorRender(lipgloss.Color(style.color), footerBGColor).
+		return stringColorRender(lipgloss.Color(style.Color), footerBGColor).
 			Background(footerBGColor).
-			Render(style.icon+" ") +
+			Render(style.Icon+" ") +
 			filePanelStyle.Render(truncateTextBeginning(name, width, "..."))
 	}
 }
@@ -111,12 +111,18 @@ func formatFileSize(size int64) string {
 		return "0B"
 	}
 
-	units := []string{"B", "KB", "MB", "GB", "TB", "PB", "EB"}
+	unitsDec := []string{"B", "kB", "MB", "GB", "TB", "PB", "EB"}
+	unitsBin := []string{"B", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB"}
 
-	unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(1024)))
-	adjustedSize := float64(size) / math.Pow(1024, float64(unitIndex))
-
-	return fmt.Sprintf("%.2f %s", adjustedSize, units[unitIndex])
+	if (Config.FileSizeUseSI) {
+		unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(1000)))
+		adjustedSize := float64(size) / math.Pow(1000, float64(unitIndex))
+		return fmt.Sprintf("%.2f %s", adjustedSize, unitsDec[unitIndex])
+	} else {
+		unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(1024)))
+		adjustedSize := float64(size) / math.Pow(1024, float64(unitIndex))
+		return fmt.Sprintf("%.2f %s", adjustedSize, unitsBin[unitIndex])
+	}
 }
 
 // Truncate line lengths and keep ANSI
@@ -125,7 +131,9 @@ func checkAndTruncateLineLengths(text string, maxLength int) string {
 	var result strings.Builder
 
 	for _, line := range lines {
-		truncatedLine := ansi.Truncate(line, maxLength, "")
+		// Replace tabs with spaces
+		expandedLine := strings.ReplaceAll(line, "\t", strings.Repeat(" ", 4))
+		truncatedLine := ansi.Truncate(expandedLine, maxLength, "")
 		result.WriteString(truncatedLine + "\n")
 	}
 
